<?php

namespace Ministra\Lib\RESTAPI\v1;

use Ministra\Lib\q8ebe46aec71cfac58101535cac5d7036\n5874049a9a642db76cc69dcdf71f763f;
use Ministra\Lib\q8ebe46aec71cfac58101535cac5d7036\w32664a3d7998489dd1ffb969d1d85dc6;
use Ministra\Lib\q8ebe46aec71cfac58101535cac5d7036\b2b3e549f2ab456e466c9de1308ec925;
use Ministra\Lib\Reseller;
use Ministra\Lib\User;
class RESTCommandAccounts extends \Ministra\Lib\RESTAPI\v1\RESTCommand
{
    public function get(\Ministra\Lib\RESTAPI\v1\RESTRequest $request)
    {
        $identifiers = $request->getIdentifiers();
        $users_ids = $this->getUsersIdsFromIdentifiers($identifiers);
        if (\count($identifiers) == 1 && \count($users_ids) == 0) {
            throw new \Ministra\Lib\RESTAPI\v1\RESTCommandException('Account not found');
        }
        if ($identifiers != null && \count($identifiers) > \count($users_ids)) {
            throw new \Ministra\Lib\RESTAPI\v1\RESTCommandException('One or more identifiers are incorrect');
        }
        $result = [];
        foreach ($users_ids as $user_id) {
            $user = \Ministra\Lib\User::getInstance($user_id);
            $result[] = $user->getAccountInfo();
            \Ministra\Lib\User::clear();
        }
        return $result;
    }
    protected function getUsersIdsFromIdentifiers($identifiers)
    {
        if (!empty($identifiers[0]) && \strlen($identifiers[0]) >= 12 && \strpos($identifiers[0], ':')) {
            return \Ministra\Lib\q8ebe46aec71cfac58101535cac5d7036\b2b3e549f2ab456e466c9de1308ec925::c8135a9a2047ed3f39a823008ac828ff($identifiers);
        }
        return \Ministra\Lib\q8ebe46aec71cfac58101535cac5d7036\b2b3e549f2ab456e466c9de1308ec925::f30561de43c5dbfe777e6c27e2ac87b9f($identifiers);
    }
    public function create(\Ministra\Lib\RESTAPI\v1\RESTRequest $request)
    {
        $data = $request->getData();
        if (empty($data)) {
            throw new \Ministra\Lib\RESTAPI\v1\RESTCommandException('HTTP POST data is empty');
        }
        $allowed_to_update_fields = ['login', 'password', 'full_name', 'phone', 'account_number', 'tariff_plan', 'tariff_expired_date', 'tariff_instead_expired', 'status', 'stb_mac', 'comment', 'end_date', 'account_balance'];
        if (\Ministra\Lib\q8ebe46aec71cfac58101535cac5d7036\n5874049a9a642db76cc69dcdf71f763f::getSafe('allow_resellers_info_for_api', false)) {
            $allowed_to_update_fields[] = 'reseller_id';
        }
        $account = \array_intersect_key($data, \array_fill_keys($allowed_to_update_fields, true));
        if (empty($account)) {
            throw new \Ministra\Lib\RESTAPI\v1\RESTCommandException('Insert data is empty');
        }
        if (!empty($account['stb_mac'])) {
            $mac = \Ministra\Lib\q8ebe46aec71cfac58101535cac5d7036\w32664a3d7998489dd1ffb969d1d85dc6::b6e77c7930127d8ca62496e89b1a0e40($account['stb_mac']);
            if (!$mac) {
                throw new \Ministra\Lib\RESTAPI\v1\RESTCommandException('Not valid mac address');
            }
            $account['stb_mac'] = $mac;
        }
        if (empty($account['login'])) {
            throw new \Ministra\Lib\RESTAPI\v1\RESTCommandException('Login required');
        }
        $user = \Ministra\Lib\User::getByLogin($account['login']);
        if (!empty($user)) {
            throw new \Ministra\Lib\RESTAPI\v1\RESTCommandException('Login already in use');
        }
        if (!empty($account['stb_mac'])) {
            $user = \Ministra\Lib\User::getByMac($account['stb_mac']);
            if (!empty($user)) {
                throw new \Ministra\Lib\RESTAPI\v1\RESTCommandException('MAC address already in use');
            }
        }
        if (!empty($account['reseller_id'])) {
            $reseller = new \Ministra\Lib\Reseller($account['reseller_id']);
            if (empty($reseller->getDBData())) {
                throw new \Ministra\Lib\RESTAPI\v1\RESTCommandException('Reseller does not exist');
            }
        }
        return (bool) \Ministra\Lib\User::createAccount($account);
    }
    public function update(\Ministra\Lib\RESTAPI\v1\RESTRequest $request)
    {
        $data = $request->getData();
        if (empty($data)) {
            throw new \Ministra\Lib\RESTAPI\v1\RESTCommandException('HTTP POST data is empty');
        }
        $allowed_to_update_fields = ['login', 'password', 'full_name', 'phone', 'account_number', 'tariff_plan', 'tariff_expired_date', 'tariff_instead_expired', 'status', 'stb_mac', 'comment', 'end_date', 'account_balance'];
        if (\Ministra\Lib\q8ebe46aec71cfac58101535cac5d7036\n5874049a9a642db76cc69dcdf71f763f::getSafe('allow_resellers_info_for_api', false)) {
            $allowed_to_update_fields[] = 'reseller_id';
        }
        $account = \array_intersect_key($data, \array_fill_keys($allowed_to_update_fields, true));
        if (empty($account)) {
            throw new \Ministra\Lib\RESTAPI\v1\RESTCommandException('Insert data is empty');
        }
        $identifiers = $request->getIdentifiers();
        if (\count($identifiers) == 0) {
            throw new \Ministra\Lib\RESTAPI\v1\RESTCommandException('Identifier required');
        }
        $users_ids = $this->getUsersIdsFromIdentifiers($identifiers);
        if (\count($identifiers) == 1 && \count($users_ids) == 0) {
            throw new \Ministra\Lib\RESTAPI\v1\RESTCommandException('Account not found');
        }
        if (\count($identifiers) > 1) {
            throw new \Ministra\Lib\RESTAPI\v1\RESTCommandException('Only one identifier allowed');
        }
        if (!empty($account['login'])) {
            $user = \Ministra\Lib\User::getByLogin($account['login']);
            if (!empty($user) && ($user->getId() != $users_ids[0] || \count($users_ids) > 1)) {
                throw new \Ministra\Lib\RESTAPI\v1\RESTCommandException('Login already in use');
            }
        }
        if (!empty($account['reseller_id'])) {
            $reseller = new \Ministra\Lib\Reseller($account['reseller_id']);
            if (empty($reseller->getDBData())) {
                throw new \Ministra\Lib\RESTAPI\v1\RESTCommandException('Reseller does not exist');
            }
        }
        $result = true;
        foreach ($users_ids as $user_id) {
            $user = \Ministra\Lib\User::getInstance($user_id);
            $result = $user->updateAccount($account) && $result;
            \Ministra\Lib\User::clear();
        }
        return $result;
    }
    public function delete(\Ministra\Lib\RESTAPI\v1\RESTRequest $request)
    {
        $identifiers = $request->getIdentifiers();
        if (\count($identifiers) == 0) {
            throw new \Ministra\Lib\RESTAPI\v1\RESTCommandException('Identifier required');
        }
        $users_ids = $this->getUsersIdsFromIdentifiers($identifiers);
        if (\count($identifiers) == 1 && \count($users_ids) == 0) {
            throw new \Ministra\Lib\RESTAPI\v1\RESTCommandException('Account not found');
        }
        if (\count($identifiers) > 1) {
            throw new \Ministra\Lib\RESTAPI\v1\RESTCommandException('Only one identifier allowed');
        }
        $result = true;
        foreach ($users_ids as $user_id) {
            $user = \Ministra\Lib\User::getInstance($user_id);
            $result = $user->delete() && $result;
            \Ministra\Lib\User::clear();
        }
        return $result;
    }
}
